@@ -3,10 +3,10 @@ package Pod::ProjectDocs::Doc;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_005';    # TRIAL VERSION
+our $VERSION = '0.48_006';    # TRIAL VERSION
 
 use Moose;
-extends 'Pod::ProjectDocs::File';
+with 'Pod::ProjectDocs::File';
 
 use File::Basename;
 use File::Spec;
