@@ -3,9 +3,9 @@ package Pod::ProjectDocs::File;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_005';    # TRIAL VERSION
+our $VERSION = '0.48_006';    # TRIAL VERSION
 
-use Moose;
+use Moose::Role;
 use IO::File;
 use Carp();
 
